@@ -1,7 +1,6 @@
 from typing import (
     List,
     Optional,
-    Tuple,
 )
 from typing_extensions import (
     Final,
@@ -11,17 +10,26 @@ from .constants import (
     Command,
     Constant,
     Register,
-    SpinCommand,
-    SpinValue,
     Status,
 )
 from .utility import (
+    toByteArrayWithLength,
     toInt,
 )
 
 
 class SpiStub:
+    """Type definition for Spi class
+    """
     def xfer2(self, data: List[int]) -> List[int]:
+        """spidev.xfer2:
+            1. Toggles Chip Select
+            2. transfers list of bytes
+            3. Toggles Chip Select (to latch data)
+
+        :data: List of bytes to write
+        :return: List of bytes from MISO pin
+        """
         pass
 
 
@@ -48,64 +56,74 @@ class SpinDevice:
 
         self._direction                 = Constant.DirForward
 
-    def _writeByte(self, byte_value: int) -> int:
+    def _write(self, data: int) -> int:
         """Write a single byte to the device.
 
-        :byte_value: A single byte to send to the device
+        :data: A single byte representing a command or value
         :return: Returns response byte
         """
-        assert(byte_value >= 0)
-        assert(byte_value <= 0xFF)
+        assert data >= 0
+        assert data <= 0xFF
 
         buffer = [0] * self._total_devices
-        buffer[self._position] = byte_value
-
-        print(buffer)
+        buffer[self._position] = data
 
+        # TODO: CS LOW
         response = self._spi.xfer2(buffer)
+        # TODO: CS HIGH
 
         return response[self._position]
 
-    def _write(self, value: SpinValue) -> List[int]:
-        """Write each byte in data to device
-        Used to combine calls to _writeByte
+    def _writeMultiple(self, data: List[int]) -> int:
+        """Write each byte in list to device
+        Used to combine calls to _write
 
-        :value: SpinValue containing Bytes to send
-        :return: Response as a list of bytes
+        :data: List of single byte values to send
+        :return: Response bytes as int
         """
         response = []
 
-        for byte_value in value.Bytes:
-            response.append(self._writeByte(byte_value))
+        for data_byte in data:
+            response.append(self._write(data_byte))
 
-        return response
+        return toInt(response)
 
-    def _writeCommand(self, command: SpinCommand) -> SpinValue:
+    def _writeCommand(
+            self, command: int,
+            payload: Optional[int] = None,
+            payload_size: Optional[int] = None) -> int:
         """Write command to device with payload (if any)
 
         :command: Command to write
         :payload: Payload (if any)
-        :return: Response as SpinValue
+        :payload_size: Payload size in bytes
+        :return: Response bytes as int
         """
+        assert (payload is None) == (payload_size is None), \
+            'payload and payload_size must be either both None, xor present'
+
         response = self._write(command)
 
-        if command.payload is not None:
-            response += self._write(command.payload)
+        # payload_size does not need to be checked here,
+        # but mypy is not quite that advanced yet
+        if payload is None or payload_size is None:
+            return response
 
-        return SpinValue(response)
+        return self._writeMultiple(
+            toByteArrayWithLength(payload, payload_size)
+        )
 
-    def setRegister(self, register: int, value: int) -> SpinValue:
+    def setRegister(self, register: int, value: int) -> None:
         """Set the specified register to the given value
         :register: The register location
         :value: Value register should be set to
         """
-        _value = SpinValue(value, Register.getSize(register))
+        RegisterSize = Register.getSize(register)
         set_command = Command.ParamSet | register
-        set_command.setPayload(_value)
 
-        return self._writeCommand(set_command)
+        self._writeCommand(set_command, value, RegisterSize)
 
-    def getRegister(self, register: int) -> SpinValue:
+    def getRegister(self, register: int) -> int:
         """Fetches a register's contents and returns the current value
 
         :register: Register location to be accessed
@@ -113,20 +131,9 @@ class SpinDevice:
 
         """
         RegisterSize = Register.getSize(register)
-        print(f'Wat: {Command.ParamGet} | {register}')
-        print(f'Command val should be {Command.ParamGet | register}')
         self._writeCommand(Command.ParamGet | register)
 
-        response_bytes: List[int] = []
-
-        print('Kwokka')
-        for _ in range(RegisterSize):
-            response_bytes += self._write(Command.Nop)
-            print(f'Growing: {response_bytes}')
-
-        print('Kwokka DONE')
-
-        return SpinValue(response_bytes)
+        return self._writeMultiple([Command.Nop] * RegisterSize)
 
     def move(self, steps: int) -> None:
         """Move motor n steps
@@ -134,12 +141,12 @@ class SpinDevice:
         :steps: Number of (micro)steps to take
 
         """
-        assert(steps >= 0)
-        assert(steps <= Constant.MaxSteps)
+        assert steps >= 0
+        assert steps <= Constant.MaxSteps
 
-        command = (Command.Move | self._direction)
-        command.setPayload(steps)
-        self._writeCommand(command)
+        PayloadSize = Command.getPayloadSize(Command.Move)
+
+        self._writeCommand(Command.Move | self._direction, steps, PayloadSize)
 
     def run(self, steps_per_second: float) -> None:
         """Run the motor at the given steps per second
@@ -148,23 +155,22 @@ class SpinDevice:
         0.015 step/s resolution
 
         """
-        assert(steps_per_second >= 0)
-        assert(steps_per_second <= Constant.MaxStepsPerSecond)
+        assert steps_per_second >= 0
+        assert steps_per_second <= Constant.MaxStepsPerSecond
 
         speed = int(steps_per_second * Constant.SpsToSpeed)
-        command = (Command.Run | self._direction)
-        command.setPayload(speed)
+        PayloadSize = Command.getPayloadSize(Command.Run)
 
-        self._writeCommand(command)
+        self._writeCommand(Command.Run | self._direction, speed, PayloadSize)
 
-    def setDirection(self, direction: SpinValue) -> None:
+    def setDirection(self, direction: int) -> None:
         """Set motor direction. Does not affect active movement
 
         :direction: Direction as declared in Constant
 
         """
-        assert(direction >= 0)
-        assert(direction < Constant.DirMax)
+        assert direction >= 0
+        assert direction < Constant.DirMax
 
         self._direction = direction
 
@@ -192,16 +198,13 @@ class SpinDevice:
         """
         self._writeCommand(Command.StopSoft)
 
-    def getStatus(self) -> SpinValue:
+    def getStatus(self) -> int:
         """Get status register
         Resets alarm flags. Does not reset HiZ
-        :returns: 2 bytes status as SpinValue
+        :returns: 2 bytes status as an int
 
         """
-        self._writeCommand(Command.Status)
-        response_bytes = self._write(SpinValue([Command.Nop] * 2))
-
-        return SpinValue(response_bytes)
+        return self._writeCommand(Command.StatusGet)
 
     def isBusy(self) -> bool:
         """Checks busy status of the device
@@ -212,4 +215,4 @@ class SpinDevice:
         # So as not to clear any warning flags
         status = self.getRegister(Register.Status)
 
-        return False if (status.Value & Status.NotBusy) else True
+        return False if (status & Status.NotBusy) else True
